// *#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#*#* Configuration.h *#*#*#*#*#*#*#*#*#* (C) 2023 DekTec
//
// Code example AvFifo_VideoTx - Configuration
// 
// Standard configuration:
// - Video frame resolution: 1920x1080 pixels
// - IP address for transmission: 239, 10, 10, 10, port 5000
// - SMPTE 2110-20 video format: 10-bit YCbCr-4:2:2, 50Hz
// - Number of balls in the simulation: 200
// - Ball radius: 5-30 pixels, ball speed 0-2 pixels/frame
//

// -.-.-.-.-.-.-.-.-.-.-.- Include necessary headers and libraries -.-.-.-.-.-.-.-.-.-.-.-

#include "DTAPI_AvFifo.h"           // DekTec's AvFifo API, part of DTAPI.
#include "Generator.h"              // SMPTE 2110 video frame generator.

using namespace std;                // Avoid std:: prefix for standard library calls.
using namespace AvFifo;             // Avoid AvFifo:: prefix, keeping code concise.

// .-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.- Configuration -.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.

// If a config value can be changed without changing the application code, it is 
// labeled "CONFIGURABLE".

// DTA-2110 device number: 0=First DTA-2110 in the system, 1=Second one, etc.
constexpr int Dta2110DeviceNo{0};                // CONFIGURABLE

// -.-.-.-.-.-.-.-.-.-.-.-.-.- SMPTE 2110 video configuration -.-.-.-.-.-.-.-.-.-.-.-.-.-.

// Fixed frame size (1920x1080 pixels).
constexpr int FrameWidth{1920};                  // CONFIGURABLE
constexpr int FrameHeight{1080};                 // CONFIGURABLE

// IP transmit configuration parameters.
const IpPars AvFifo_VideoTx_IpPars
{
    .IpAddr{239, 10, 10, 10},                    // CONFIGURABLE
    .IpVersion{IpProtocolVersion::IPv4},         // CONFIGURABLE
    .Port{5000},                                 // CONFIGURABLE
    // For SMPTE 2110, transport protocol must be set to RTP.
    .RtpPayloadType{96},
    .TransportProtocol{IpTransportProtocol::Rtp}
};

// SMPTE 2110 video format.
const St2110::TxConfigVideo AvFifo_VideoTx_Config
{
    .Format{St2110::TxFrameFormat::Uyvy422_10b},
    .Packing{false, St2110::PackingMode::General, -1},
    .Resolution{FrameWidth, FrameHeight},
    .Timing{{50, 1}, St2110::Scheduling::Linear, St2110::VideoScanning::Progressive}
};

// .-.-.-.-.-.-.-.-.-.-.-.- Moving balls simulation configuration -.-.-.-.-.-.-.-.-.-.-.-.

// Number of simulated moving balls.
constexpr int NumMovingBalls{200};               // CONFIGURABLE

// Minimum and maximum radius of the balls.
constexpr int MinBallRadius{5};                  // CONFIGURABLE
constexpr int MaxBallRadius{30};                 // CONFIGURABLE

// Minimum and maximum initial velocity of the balls in #pixels moved per frame.
constexpr double MinBallSpeed{0};                // CONFIGURABLE
constexpr double MaxBallSpeed{2};                // CONFIGURABLE

// The frame's background color.
constexpr Color BackgroundColor{80, 200, 0};     // CONFIGURABLE
